@@ -1,5 +1,6 @@
 #!/usr/bin/perl
 
+use 5.008;
 use strict;
 use warnings;
 
@@ -18,12 +19,12 @@ BEGIN {
     unshift @INC, File::Spec->catdir($cwd, 'lib');
 }
 
-use Test::Unit::Lite;
+use Test::Unit::Lite 0.11;
+use Test::Assert;
 
-use Exception::Base
-    max_arg_nums => 0, max_arg_len => 200, verbosity => 4,
-    '+ignore_package' => [ qr/^Test::Unit::/, 'main' ];
-use Exception::Warning '%SIG' => 'die';
-use Exception::Died    '%SIG' => 'die';
+use Exception::Base max_arg_nums => 0, max_arg_len => 200, verbosity => 4;
+use Exception::Warning '%SIG' => 'die', verbosity => 4;
+use Exception::Died '%SIG', verbosity => 4;
+use Exception::Assertion verbosity => 4;
 
 all_tests;
